@@ -2,15 +2,14 @@
 Avakas Built-In Project Flavors
 """
 
-from .base import AvakasProject, AvakasGitProject
+from .base import AvakasLegacy
 from .ansible import AvakasAnsibleProject
 from .chef import AvakasChefProject
 from .erlang import AvakasErlangProject
 from .node import AvakasNodeProject
 
 __all__ = [
-    'AvakasProject',
-    'AvakasGitProject',
+    'AvakasLegacy',
     'AvakasAnsibleProject',
     'AvakasChefProject',
     'AvakasErlangProject',
